declare const BLOCK_NUMBERS: readonly [1, 2, 3, 4, 5, 6, 7];
declare type BlockNumber = typeof BLOCK_NUMBERS[number];
declare type Item = {
    type: "image";
    url: string;
} | {
    type: "text";
    text: string;
};
declare type Results = Record<BlockNumber, {
    completionTimeMs: number;
    correct: boolean;
}[]>;
declare type Choice = "left" | "right";
declare type TrialOption<CategoryT, TargetT> = {
    category?: CategoryT;
    target?: TargetT;
};
declare type IATStage<CategoryT, TargetT> = {
    testComplete: false;
    block: number;
    trial: number;
    left: TrialOption<CategoryT, TargetT>;
    right: TrialOption<CategoryT, TargetT>;
    item: Item;
    correctChoice: Choice;
    next: (completionTimeMs: number, correct: boolean) => IATStage<CategoryT, TargetT>;
} | {
    testComplete: true;
    results: Results;
};
declare function IAT<CategoryT extends string, TargetT extends string>(options: {
    categories: Record<CategoryT, Item[]>;
    targets: Record<TargetT, Item[]>;
    trialsPerBlock: Record<BlockNumber, number>;
}): IATStage<CategoryT, TargetT>;

export { BlockNumber, Choice, IAT, IATStage, Item, Results, TrialOption };
